import { KernelMessage } from '@jupyterlab/services';
import { ISignal } from '@lumino/signaling';
/**
 * The Bytecode model
 */
export declare class BytecodeModel {
    /**
     * Get the bytecode output.
     */
    get output(): string;
    /**
     * Get the error message.
     */
    get error(): string;
    /**
     * Whether this is a light theme.
     */
    get isLight(): boolean;
    /**
     * Set the theme to light or dark.
     * @value true if light, false otherwise
     */
    set isLight(value: boolean);
    /**
     * Get the selected lines from the editor.
     */
    get selectedLines(): Set<number>;
    /**
     * Set the selected lines from the editor.
     * @lines The selected lines.
     */
    set selectedLines(lines: Set<number>);
    /**
     * A signal emitted when the model changes.
     */
    get changed(): ISignal<BytecodeModel, void>;
    /**
     * Handle a message from the kernel.
     */
    handleKernelMessage: (msg: KernelMessage.IIOPubMessage<KernelMessage.IOPubMessageType>) => void;
    private _output;
    private _error;
    private _isLight;
    private _selectedLines;
    private _changed;
}
