import { Signal } from '@lumino/signaling';
/**
 * The Bytecode model
 */
export class BytecodeModel {
    constructor() {
        /**
         * Handle a message from the kernel.
         */
        this.handleKernelMessage = (msg) => {
            const msgType = msg.header.msg_type;
            const message = msg.content;
            switch (msgType) {
                case 'stream':
                    this._output = message.text;
                    this._error = '';
                    this._changed.emit(void 0);
                    break;
                case 'error':
                    console.error(msg.content);
                    this._error = message.evalue;
                    this._changed.emit(void 0);
                    break;
                default:
                    break;
            }
        };
        this._output = '';
        this._error = '';
        this._isLight = true;
        this._changed = new Signal(this);
    }
    /**
     * Get the bytecode output.
     */
    get output() {
        return this._output;
    }
    /**
     * Get the error message.
     */
    get error() {
        return this._error;
    }
    /**
     * Whether this is a light theme.
     */
    get isLight() {
        return this._isLight;
    }
    /**
     * Set the theme to light or dark.
     * @value true if light, false otherwise
     */
    set isLight(value) {
        this._isLight = value;
        this._changed.emit(void 0);
    }
    /**
     * Get the selected lines from the editor.
     */
    get selectedLines() {
        return this._selectedLines;
    }
    /**
     * Set the selected lines from the editor.
     * @lines The selected lines.
     */
    set selectedLines(lines) {
        this._selectedLines = lines;
        this._changed.emit(void 0);
    }
    /**
     * A signal emitted when the model changes.
     */
    get changed() {
        return this._changed;
    }
}
