import { ISessionContext, IThemeManager } from '@jupyterlab/apputils';
import { IObservableMap } from '@jupyterlab/observables';
import { CodeEditor } from '@jupyterlab/codeeditor';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { ServiceManager } from '@jupyterlab/services';
import { ReadonlyJSONObject } from '@lumino/coreutils';
import { Message } from '@lumino/messaging';
import { Panel } from '@lumino/widgets';
import { BytecodeModel } from './model';
/**
 * The panel that shows the Bytecode preview
 */
export declare class PythonBytecodePanel extends Panel {
    /**
     * Constructor for the panel.
     *
     * @param options: the instantiation options.
     */
    constructor(options: PythonBytecodePanel.IOptions);
    /**
     * Get the model.
     */
    get model(): BytecodeModel;
    /**
     * Get the session context.
     */
    get sessionContext(): ISessionContext;
    /**
     * Dispose the panel.
     */
    dispose(): void;
    /**
     * Setup the panel.
     */
    setup(): Promise<void>;
    /**
     * Handle onCloseRequest messages.
     * @param msg The message
     */
    protected onCloseRequest(msg: Message): void;
    /**
     * Setup the listeners.
     */
    private _setupListeners;
    /**
     * Remove the listeners.
     */
    private _removeListeners;
    /**
     * Evaluate the content of the document.
     * @param content the content to evaluate
     */
    private _evaluateContent;
    /**
     * Get the content of the model.
     */
    private _getModelContent;
    /**
     * Get the content of the file.
     */
    private _getFileContent;
    /**
     * Execute code.
     * @param code The code to execute
     */
    private _execute;
    /**
     * Change the theme to the current theme.
     */
    private _changeTheme;
    /**
     * Handle a kernel changed event.
     */
    private _handleKernelChanged;
    /**
     * Handle a seleection changed event.
     */
    private _handleSelectionChanged;
    private _monitor;
    private _fileContext;
    private _docManager;
    private _themeManager;
    private _selections;
    private _sessionContext;
    private _model;
    private _view;
}
/**
 * A namespace for PythonBytecodePanel statics.
 */
export declare namespace PythonBytecodePanel {
    interface IOptions {
        /**
         * The service manager used to get a list
         * of sessions
         */
        serviceManager: ServiceManager.IManager;
        /**
         * The document manager is used to get a context
         * for the file being edited
         */
        docManager: IDocumentManager;
        /**
         * The theme manager used by the panel
         * to control the style of code highlighting
         */
        themeManager: IThemeManager;
        /**
         * Use preferences for the bytecode extension
         */
        userSettings: ReadonlyJSONObject;
        /**
         * Editor selections
         */
        selections: IObservableMap<CodeEditor.ITextSelection[]>;
        /**
         * Path of an existing session
         */
        path?: string;
        /**
         * The base path for a new client session
         */
        basePath?: string;
        /**
         * The name of the client session
         */
        name?: string;
        /**
         * A kernel preference.
         */
        kernelPreference?: ISessionContext.IKernelPreference;
    }
}
